==> ag_1.14.0.tar.gz: ag/man/agPATH.Rd <==
\name{agPATH}
\alias{agPATH}
\title{Mappings between probe identifiers and KEGG pathway identifiers}
\description{
  KEGG (Kyoto Encyclopedia of Genes and Genomes) maintains pathway data
  for various organisms. agPATH maps probe identifiers to the
  identifiers used by KEGG for pathways in which the genes represented
  by the probe identifiers are involved
}
\details{
  Each KEGG pathway has a name and identifier. Pathway name for a given pathway
  identifier can be obtained using the KEGG data package that can either be
  built using AnnBuilder or downloaded from Bioconductor
  \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  url{http://www.genome.ad.jp/kegg/pathway.html} by using pathway identifiers as
  keys.   

  Mappings were based on data provided by:

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair//ath/ath_gene_map.tab}
Built: N/A

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy_AG_array_elements-2006-07-14.txt}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/User_Requests/LocusPublished.08012006.txt}
Built: N/A

  Package built Wed Sep  6 11:22:37 2006
}
\references{
  \url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(agPATH)
    # Remove probe identifiers that do not map to any pathway id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The pathway identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}
\keyword{datasets}

==> ag_1.16.1.tar.gz: ag/man/agPATH.Rd <==
\name{agPATH}
\alias{agPATH}
\title{Mappings between probe identifiers and KEGG pathway identifiers}
\description{
  KEGG (Kyoto Encyclopedia of Genes and Genomes) maintains pathway data
  for various organisms. agPATH maps probe identifiers to the
  identifiers used by KEGG for pathways in which the genes represented
  by the probe identifiers are involved
}
\details{
  Each KEGG pathway has a name and identifier. Pathway name for a given pathway
  identifier can be obtained using the KEGG data package that can either be
  built using AnnBuilder or downloaded from Bioconductor
  \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  url{http://www.genome.ad.jp/kegg/pathway.html} by using pathway identifiers as
  keys.   

  Mappings were based on data provided by:

  Tair: \\url{ftp://ftp.arabidopsis.org/home/tair//ath/ath\_gene\_map.tab}
Built: N/A

  Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy\_AG\_array\_elements-2006-07-14.txt}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR\_sequenced\_genes}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/User\_Requests/LocusPublished.02022007}
Built: N/A

  Package built Thu Mar 15 17:42:16 2007
}
\references{
  \url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(agPATH)
    # Remove probe identifiers that do not map to any pathway id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The pathway identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}
\keyword{datasets}
